quantizationtools.QGridQuantizer
================================

.. inheritance-diagram:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer
   :private-bases:

.. autoclass:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.beatspan

.. autoattribute:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.beatspan_ms

.. autoattribute:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.search_tree

.. autoattribute:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.tempo

.. autoattribute:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.tempo_lookup

.. autoattribute:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.threshold

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__call__

   .. note:: Inherited from :py:class:`quantizationtools._Quantizer <abjad.tools.quantizationtools._Quantizer._Quantizer._Quantizer>`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__repr__

   .. note:: Inherited from :py:class:`quantizationtools._Quantizer <abjad.tools.quantizationtools._Quantizer._Quantizer._Quantizer>`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridQuantizer.QGridQuantizer.QGridQuantizer.__str__

   .. note:: Inherited from `__builtin__.object`
